.. stalker documentation master file, created by
   sphinx-quickstart on Sat Jul  3 13:41:00 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*******
Stalker
*******

.. include:: source/../../../README

Table of Contents
=================

.. toctree::
    :maxdepth: 1
    
    installation.rst
    tutorial.rst
    design.rst
    contribute.rst
    roadmap.rst
    changelog.rst


Summary
-------

.. autosummary::
   :toctree: generated/
   :nosignatures:
   
   stalker.db
   stalker.db.engine
   stalker.db.mapper
   stalker.db.metadata
   stalker.db.mixin
   stalker.db.mixin.ReferenceMixinDB
   stalker.db.mixin.StatusMixinDB
   stalker.db.mixin.ScheduleMixinDB
   stalker.db.tables
   stalker.db.query
   stalker.db.session
   stalker.db.setup
   stalker.core.errors
   stalker.core.errors.CircularDependencyError
   stalker.core.errors.LoginError
   stalker.core.errors.DBError
   stalker.core.mixins
   stalker.core.mixins.ReferenceMixin
   stalker.core.mixins.ScheduleMixin
   stalker.core.mixins.StatusMixin
   stalker.core.mixins.TaskMixin
   stalker.core.models
   stalker.core.models.Asset
   stalker.core.models.Booking
   stalker.core.models.Comment
   stalker.core.models.Department
   stalker.core.models.FilenameTemplate
   stalker.core.models.Entity
   stalker.core.models.ImageFormat
   stalker.core.models.Link
   stalker.core.models.Message
   stalker.core.models.Note
   stalker.core.models.PermissionGroup
   stalker.core.models.Project
   stalker.core.models.Repository
   stalker.core.models.Sequence
   stalker.core.models.Shot
   stalker.core.models.SimpleEntity
   stalker.core.models.Status
   stalker.core.models.StatusList
   stalker.core.models.Structure
   stalker.core.models.Tag
   stalker.core.models.Task
   stalker.core.models.Type
   stalker.core.models.User
   stalker.core.models.Version
   stalker.ext.auth
   stalker.ext.auth.authenticate
   stalker.ext.auth.check_password
   stalker.ext.auth.create_session
   stalker.ext.auth.login
   stalker.ext.auth.login_required
   stalker.ext.auth.logout
   stalker.ext.auth.permission_required
   stalker.ext.auth.set_password
   stalker.ext.validatedList
   stalker.ext.validatedList.ValidatedList
   stalker.utils.path_to_exec

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

